==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebTabHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        WebTabHeaderConnectionEventArgsDescriptionMetadata.d(a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
        a.item("Detail", "ExportedType:WebTabHeaderConnectionEventArgs");
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.u("WebTabHeaderConnectionEventArgs", function () { return new WebTabHeaderConnectionEventArgsDescription(); });
        a.t("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebTabHeaderConnectionEventArgsDescriptionMetadata };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebTabHeaderElementDescriptionMetadata } from "./WebTabHeaderElementDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebTabHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
        WebTabHeaderElementDescriptionMetadata.d(a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
        a.item("Pane", "ExportedType:WebContentPane");
        a.item("Element", "ExportedType:WebTabHeaderElement");
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.u("WebTabHeaderConnectionEventArgs", function () { return new WebTabHeaderConnectionEventArgsDescription(); });
        a.t("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebTabHeaderConnectionEventArgsDescriptionMetadata };
